@@ -6,7 +6,7 @@
 #' 
 #' @examples 
 #' 
-#' hc_demo() %>% 
+#' highcharts_demo() %>% 
 #'   hc_add_theme(hc_theme_gridlight())
 #' 
 #' @export
@@ -14,8 +14,8 @@ hc_theme_gridlight <- function(...){
   
   theme <-  
   list(
-    colors = c("#7cb5ec", "#f7a35c", "#90ee7e", "#7798BF", "#aaeeee", "#ff0066", "#eeaaee",
-             "#55BF3B", "#DF5353", "#7798BF", "#aaeeee"),
+    colors = c("#7CB5EC", "#F7A35C", "#90EE7E", "#7798BF",
+               "#AAEEEE", "#FF0066", "#EEAAEE", "#55BF3B"),
     chart = list(
       backgroundColor = NULL,
       style = list(
@@ -24,50 +24,50 @@ hc_theme_gridlight <- function(...){
     ),
     title = list(
       style = list(
-        fontSize = '16px',
-        fontWeight = 'bold',
-        textTransform = 'uppercase'
+        fontSize = "16px",
+        fontWeight = "bold",
+        textTransform = "uppercase"
       )
     ),
     tooltip = list(
       borderWidth = 0,
-      backgroundColor = 'rgba(219,219,216,0.8)',
+      backgroundColor = "rgba(219,219,216,0.8)",
       shadow = FALSE
     ),
     legend = list(
       itemStyle = list(
-        fontWeight = 'bold',
-        fontSize = '13px'
+        fontWeight = "bold",
+        fontSize = "13px"
       )
     ),
     xAxis = list(
       gridLineWidth = 1,
       labels = list(
         style = list(
-          fontSize = '12px'
+          fontSize = "12px"
         )
       )
     ),
     yAxis = list(
-      minorTickInterval = 'auto',
+      minorTickInterval = "auto",
       title = list(
         style = list(
-          textTransform = 'uppercase'
+          textTransform = "uppercase"
         )
       ),
       labels = list(
         style = list(
-          fontSize = '12px'
+          fontSize = "12px"
         )
       )
     ),
     plotOptions = list(
       candlestick = list(
-        lineColor = '#404048'
+        lineColor = "#404048"
       )
     ),
   
-    background2 = '#F0F0EA'
+    background2 = "#F0F0EA"
     
   )
   
